@@ -22,7 +22,7 @@
 {
     'name': 'GNU Health : Free Health and Hospital Information System',
     'name_es_ES': 'GNU Health : Sistema Libre de Gestión Hospitalaria y de Salud',
-    'version': '1.6.2',
+    'version': '1.6.3',
     'author': 'GNU Solidario',
     'email': 'health@gnusolidario.org',
     'website': 'http://health.gnu.org',
@@ -153,10 +153,5 @@ Características de GNU Health :
         'health_report.xml',
     ],
     'translation': [
-        'locale/es_ES.po',
-        'locale/fr_FR.po',
-        'locale/el.po',
-        'locale/fa.po',
-        'locale/it.po',
     ],
 }
