@@ -21,7 +21,7 @@
 ##############################################################################
 {
     'name': 'GNU Health: Calendar',
-    'version': '1.6.2',
+    'version': '1.6.3',
     'author': 'GNU Solidario',
     'website': 'http://health.gnu.org',
     'depends': [
@@ -33,17 +33,12 @@
     ],
     'name_es_ES': 'GNU Health : Calendario',
     'translation': [
-        'locale/es_ES.po',
-        'locale/fr_FR.po',
-        'locale/el.po',
-        'locale/fa.po',
-        'locale/it.po',
     ],
-    'description': ''' 
+    'description': '''
         This module add functionality to connect with a CalDAV client.
         ''',
-    'description_es_ES': ''' 
-        Este módulo añade funcionalidad para conectar con un cliente CalDAV, 
+    'description_es_ES': '''
+        Este módulo añade funcionalidad para conectar con un cliente CalDAV,
         ''',
 
 
