@@ -1,24 +1,24 @@
-# coding=utf-8
-
-#    Copyright (C) 2008-2012 Luis Falcon
-
+# -*- coding: utf-8 -*-
+##############################################################################
+#
+#    GNU Health: The Free Health and Hospital Information System
+#    Copyright (C) 2008-2012  Luis Falcon <lfalcon@gnusolidario.org>
+#
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
 #    the Free Software Foundation, either version 3 of the License, or
 #    (at your option) any later version.
-
+#
 #    This program is distributed in the hope that it will be useful,
 #    but WITHOUT ANY WARRANTY; without even the implied warranty of
 #    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 #    GNU General Public License for more details.
-
+#
 #    You should have received a copy of the GNU General Public License
 #    along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
-from trytond.model import ModelView, ModelSingleton, ModelSQL, fields
-from trytond.tools import safe_eval, datetime_strftime
-from trytond.transaction import Transaction
-from trytond.pyson import Eval
+#
+##############################################################################
+from trytond.model import ModelView, ModelSQL, fields
 
 
 class DiseaseGene(ModelSQL, ModelView):
@@ -26,17 +26,17 @@ class DiseaseGene(ModelSQL, ModelView):
     _name = 'gnuhealth.disease.gene'
     _description = __doc__
 
-    name = fields.Char('Official Symbol', select='1')
-    long_name = fields.Char('Official Long Name', select='1')
+    name = fields.Char('Official Symbol', select=True)
+    long_name = fields.Char('Official Long Name', select=True)
     gene_id = fields.Char('Gene ID',
-        help="default code from NCBI Entrez database.", select='2')
+        help="default code from NCBI Entrez database.", select=True)
     chromosome = fields.Char('Affected Chromosome',
-        help="Name of the affected chromosome", select='2')
+        help="Name of the affected chromosome", select=True)
     location = fields.Char('Location', help="Locus of the chromosome")
     dominance = fields.Selection([
         ('d', 'dominant'),
         ('r', 'recessive'),
-        ], 'Dominance', select='2')
+        ], 'Dominance', select=True)
     info = fields.Text('Information', help="Name of the protein(s) affected")
 
     def get_rec_name(self, ids, name):
@@ -56,9 +56,9 @@ class PatientGeneticRisk(ModelSQL, ModelView):
     _name = 'gnuhealth.patient.genetic.risk'
     _description = __doc__
 
-    patient = fields.Many2One('gnuhealth.patient', 'Patient', select='1')
+    patient = fields.Many2One('gnuhealth.patient', 'Patient', select=True)
     disease_gene = fields.Many2One('gnuhealth.disease.gene',
-        'Disease Gene', select='1')
+        'Disease Gene', required=True)
 
 PatientGeneticRisk()
 
@@ -68,12 +68,12 @@ class FamilyDiseases(ModelSQL, ModelView):
     _name = 'gnuhealth.patient.family.diseases'
     _description = __doc__
 
-    patient = fields.Many2One('gnuhealth.patient', 'Patient', select='1')
-    name = fields.Many2One('gnuhealth.pathology', 'Disease', select='1')
+    patient = fields.Many2One('gnuhealth.patient', 'Patient', select=True)
+    name = fields.Many2One('gnuhealth.pathology', 'Disease', required=True)
     xory = fields.Selection([
         ('m', 'Maternal'),
         ('f', 'Paternal'),
-        ], 'Maternal or Paternal', select='1')
+        ], 'Maternal or Paternal', select=True)
 
     relative = fields.Selection([
         ('mother', 'Mother'),
@@ -90,7 +90,7 @@ class FamilyDiseases(ModelSQL, ModelView):
         ], 'Relative',
         help="First degree = siblings, mother and father; second degree = " \
         "Uncles, nephews and Nieces; third degree = Grandparents and cousins",
-        select='1')
+        required=True)
 
 FamilyDiseases()
 
