@@ -20,8 +20,8 @@
 #
 ##############################################################################
 {
-    'name': 'GNU Health: Gynecology and Obstetrics',  
-    'version': '1.6.2',
+    'name': 'GNU Health: Gynecology and Obstetrics',
+    'version': '1.6.3',
     'author': 'GNU Solidario',
     'email': 'health@gnusolidario.org',
     'website': 'http://health.gnu.org',
@@ -29,15 +29,14 @@
         'health',
     ],
     'name_es_ES': 'GNU Health : Ginecología y Obstetricia',
-    'translation': ['locale/es_ES.po', 'locale/fr_FR.po', 'locale/el.po',
-        'locale/fa.po','locale/it.po'],
-
+    'translation': [
+    ],
     'description': '''
 
 This module includes :
 
 - Gynecological Information
-- Obstetric information 
+- Obstetric information
 - Perinatal Information and monitoring
 - Puerperium
 
