@@ -21,7 +21,7 @@
 ##############################################################################
 {
     'name': 'GNU Health: Inpatient administration',
-    'version': '1.6.2',
+    'version': '1.6.3',
     'author': 'GNU Solidario',
     'email': 'health@gnusolidario.org',
     'website': 'http://health.gnu.org',
@@ -29,8 +29,8 @@
         'health',
     ],
     'name_es_ES': 'GNU Health : Hospitalización',
-    'translation': ['locale/es_ES.po', 'locale/fr_FR.po', 'locale/el.po',
-        'locale/fa.po','locale/it.po'],
+    'translation': [
+    ],
 
     'description': '''
 This module will hold all the processes related to Inpatient (Patient hospitalization and bed assignment )
@@ -58,6 +58,7 @@ Contiene los procesos relacionados a la internación (Hospitalización y asignac
 
     'xml': [
         'health_inpatient_view.xml','data/health_inpatient_sequence.xml',
+        'data/inpatient_diets.xml','data/diets_beliefs.xml',
         'security/access_rights.xml'
     ],
     'active': False,
