@@ -21,7 +21,7 @@
 ##############################################################################
 {
     'name': 'GNU Health: Pediatrics',
-    'version': '1.6.2',
+    'version': '1.6.3',
     'author': 'GNU Solidario',
     'email': 'health@gnusolidario.org',
     'website': 'http://health.gnu.org',
@@ -30,8 +30,8 @@
     ],
 
     'name_es_ES': 'GNU Health : Pediatría',
-    'translation': ['locale/es_ES.po', 'locale/fr_FR.po', 'locale/el.po',
-        'locale/fa.po','locale/it.po'],
+    'translation': [
+    ],
 
     'description': '''
 	
