@@ -43,13 +43,12 @@ setup(name='trytond_health_services',
     package_dir={'trytond.modules.health_services': '.'},
     packages=[
         'trytond.modules.health_services',
-        'trytond.modules.health_services.wizard',
+        'trytond.modules.health_services.tests',
         ],
     package_data={
         'trytond.modules.health_services': info.get('xml', []) \
             + info.get('translation', []) \
             + ['report/*.odt', 'icons/*.svg'],
-
         },
     classifiers=[
         'Development Status :: 5 - Production/Stable',
